@@ -6,7 +6,7 @@
 import pytest
 
 from tests.coveragetest import CoverageTest
-from tests.helpers import assert_count_equal
+from tests.helpers import assert_count_equal, xfail_pypy_3749
 
 import coverage
 from coverage import env
@@ -14,9 +14,10 @@ from coverage.files import abs_file
 
 
 skip_cpython_92236 = pytest.mark.skipif(
-    env.PYVERSION >= (3, 11, 0, "beta"),
+    env.PYVERSION == (3, 11, 0, "beta", 1, 0),
     reason="Avoid a CPython bug: https://github.com/python/cpython/issues/92236",
     # #92236 is fixed in https://github.com/python/cpython/pull/92722
+    # and in https://github.com/python/cpython/pull/92772
 )
 
 class SimpleArcTest(CoverageTest):
@@ -279,10 +280,6 @@ class WithTest(CoverageTest):
             arcz=arcz,
         )
 
-    @pytest.mark.xfail(
-        (3, 11) <= env.PYVERSION <= (3, 11, 0, 'alpha', 2, 0),
-        reason="avoid a 3.11 bug: 45709"
-    )
     # https://github.com/nedbat/coveragepy/issues/1270
     def test_raise_through_with(self):
         if env.PYBEHAVIOR.exit_through_with:
@@ -1205,11 +1202,6 @@ class YieldTest(CoverageTest):
             arcz=".1 19 9.  .2 23 34 45 56 63 37 7.",
         )
 
-    # https://bugs.python.org/issue46225
-    @pytest.mark.xfail(
-        env.PYVERSION[:5] == (3, 11, 0, 'alpha', 3),
-        reason="avoid 3.11 bug: bpo46225",
-    )
     @skip_cpython_92236
     def test_bug_308(self):
         self.check_coverage("""\
@@ -1318,7 +1310,6 @@ class YieldTest(CoverageTest):
         )
 
 
-@pytest.mark.xfail(env.PYVERSION <= (3, 10, 0, 'beta', 4, 0), reason="3.10.0b4 had bugs")
 @pytest.mark.skipif(not env.PYBEHAVIOR.match_case, reason="Match-case is new in 3.10")
 class MatchCaseTest(CoverageTest):
     """Tests of match-case."""
@@ -1656,6 +1647,7 @@ class MiscArcTest(CoverageTest):
 class DecoratorArcTest(CoverageTest):
     """Tests of arcs with decorators."""
 
+    @xfail_pypy_3749
     def test_function_decorator(self):
         arcz = (
             ".1 16 67 7A AE EF F. "     # main line
@@ -1684,6 +1676,7 @@ class DecoratorArcTest(CoverageTest):
             arcz=arcz,
         )
 
+    @xfail_pypy_3749
     def test_class_decorator(self):
         arcz = (
             ".1 16 67 6D 7A AE E. "     # main line
@@ -1711,6 +1704,7 @@ class DecoratorArcTest(CoverageTest):
             arcz=arcz,
         )
 
+    @xfail_pypy_3749
     def test_bug_466a(self):
         # A bad interaction between decorators and multi-line list assignments,
         # believe it or not...!
@@ -1735,6 +1729,7 @@ class DecoratorArcTest(CoverageTest):
             arcz=arcz,
         )
 
+    @xfail_pypy_3749
     def test_bug_466b(self):
         # A bad interaction between decorators and multi-line list assignments,
         # believe it or not...!
@@ -1928,6 +1923,7 @@ class AsyncTest(CoverageTest):
             arcz_missing=arcz_missing,
         )
 
+    @xfail_pypy_3749
     def test_async_decorator(self):
         arcz = ".1 14 4.     .2 2.  -46 6-4 "
         if env.PYBEHAVIOR.trace_decorated_def:
@@ -1949,7 +1945,6 @@ class AsyncTest(CoverageTest):
     # https://github.com/nedbat/coveragepy/issues/1158
     # https://bugs.python.org/issue44621
     @pytest.mark.skipif(env.PYVERSION[:2] == (3, 9), reason="avoid a 3.9 bug: 44621")
-    @pytest.mark.skipif(env.PYVERSION < (3, 7), reason="need asyncio.run")
     @skip_cpython_92236
     def test_bug_1158(self):
         self.check_coverage("""\
@@ -1975,12 +1970,7 @@ class AsyncTest(CoverageTest):
 
     # https://github.com/nedbat/coveragepy/issues/1176
     # https://bugs.python.org/issue44622
-    @pytest.mark.xfail(
-        (3, 10, 0, "alpha", 0, 0) <= env.PYVERSION <= (3, 10, 0, "beta", 4, 0),
-        reason="avoid a 3.10 bug fixed after beta 4: 44622"
-    )
     @xfail_eventlet_670
-    @pytest.mark.skipif(env.PYVERSION < (3, 7), reason="need asyncio.run")
     @skip_cpython_92236
     def test_bug_1176(self):
         self.check_coverage("""\
@@ -2000,11 +1990,6 @@ class AsyncTest(CoverageTest):
         assert self.stdout() == "12\n"
 
     # https://github.com/nedbat/coveragepy/issues/1205
-    # https://bugs.python.org/issue44840
-    @pytest.mark.xfail(
-        (3, 10, 0, "alpha", 0, 0) <= env.PYVERSION <= (3, 10, 0, "candidate", 1, 0),
-        reason="avoid a 3.10 bug fixed after rc1: 44840"
-    )
     def test_bug_1205(self):
         self.check_coverage("""\
             def func():
